Struct google_appengine1_beta4::ListInstancesResponse [−][src]
pub struct ListInstancesResponse {
pub next_page_token: Option<String>,
pub instances: Option<Vec<Instance>>,
}Response message for Instances.ListInstances.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- modules versions instances list apps (response)
Fields
next_page_token: Option<String>
Continuation token for fetching the next page of results.
instances: Option<Vec<Instance>>
The instances belonging to the requested version.